@@ -1,6 +1,6 @@
 package Geo::UK::Postcode::CodePointOpen;
 
-our $VERSION = '0.004';
+our $VERSION = '0.005';
 
 use Moo;
 use Types::Path::Tiny qw/ Dir /;
@@ -26,14 +26,19 @@ sub _build_column_headers {
     my $fh = $self->doc_dir->child('Code-Point_Open_Column_Headers.csv')
         ->filehandle('<');
 
+    my $short = $self->csv->getline($fh)
+        or die "Unable to read short column headers";
+    my $long = $self->csv->getline($fh)
+        or die "Unable to read long column headers";
+
     return {
-        short => $self->csv->getline($fh),
-        long  => $self->csv->getline($fh),
+        short => $short,
+        long  => $long
     };
 }
 
 sub _build_csv {
-    my $csv = Text::CSV->new( { binary => 1, eol => "\r\n" } )
+    my $csv = Text::CSV->new( { binary => 1 } )
         or die Text::CSV->error_diag();
     return $csv;
 }
@@ -280,7 +285,7 @@ data for each postcode in data files.
 Returns a coderef iterator. Call that coderef repeatedly to get a list of
 postcode hashrefs.
 
-=head1 data_files
+=head2 data_files
 
     my @data_files = $code_point_open->data_files(
         qw/ AB10 AT3 WC /
